@@ -649,6 +649,12 @@ impl From<SecretKey> for EphemeralSecretKey {
     }
 }
 
+impl From<&SecretKey> for EphemeralSecretKey {
+    fn from(sk: &SecretKey) -> Self {
+        EphemeralSecretKey(sk.0.clone())
+    }
+}
+
 impl Generate for EphemeralSecretKey {
     fn generate() -> Self {
         Self::generate_with(&mut OsRng)
@@ -1185,4 +1191,12 @@ mod tests {
 
         assert_eq!(sk.to_vec(), esk.to_vec());
     }
+
+    #[test]
+    fn test_ephemeral_secret_key_from_ref_secret_key() {
+        let sk = SecretKey::generate();
+        let esk: EphemeralSecretKey = (&sk).into();
+
+        assert_eq!(sk.to_vec(), esk.to_vec());
+    }
 }
